@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: BibTeX.py,v 1.21 2000/05/11 08:58:35 fredgo Exp $
+# $Id: BibTeX.py,v 1.21.2.1 2000/05/22 11:37:35 fredgo Exp $
 
 # Extension module for BibTeX files
 
@@ -357,15 +357,17 @@ class DataBase (Base.DataBase):
 
         try:
             entry = iter.first ()
-            
-            if entry.key is None:
-                self.add (entry)
-            else:
-                if self.dict.has_key (entry.key):
-                    errors.append (_("%s:%d: key `%s' already defined") % (
-                        str (self.key), entry.line, entry.key.key))
+
+            if entry is not None:
+                if entry.key is None:
+                    self.add (entry)
                 else:
-                    self.dict [entry.key] = entry
+                    if self.dict.has_key (entry.key):
+                        errors.append (_("%s:%d: key `%s' already defined") % (
+                            str (self.key), entry.line, entry.key.key))
+                    else:
+                        self.dict [entry.key] = entry
+                
         except Exceptions.ParserError, err:
             errors.append (str (err))
 
