@@ -17,11 +17,13 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Refer.py,v 1.8 2000/03/14 16:06:06 fredgo Exp $
+# $Id: Refer.py,v 1.8.2.1 2000/07/24 12:29:22 fredgo Exp $
 
 # Extension module for Refer files
 
-from Pyblio import Base, Types, Fields, Config, Autoload, Open, Iterator, Utils
+# Martin Wilck <martin@tropos.de> added support for citation label field.
+
+from Pyblio import Base, Types, Fields, Config, Autoload, Open, Iterator, Utils, Key
 
 import re, string, sys
 
@@ -69,6 +71,7 @@ class ReferIterator (Iterator.Iterator):
         data   = ''
         fields = {}
         type   = None
+        label = None
 
         while 1:
 	    line = self.file.readline ()
@@ -81,8 +84,9 @@ class ReferIterator (Iterator.Iterator):
 
                 # store the current field
                 if type:
-                    
-                    if fields.has_key (type):
+                    if type == "label":
+                        label = string.join (string.split (data), ' ')
+                    elif fields.has_key (type):
                         fields [type].append (string.join (string.split (data), ' '))
                     else:
                         fields [type] = [string.join (string.split (data), ' ')]
@@ -102,6 +106,10 @@ class ReferIterator (Iterator.Iterator):
                         type = 'inproceedings'
                         break
 
+                    if fields.has_key ('publisher'):
+                        type = 'book'
+                        break
+
                     if fields.has_key ('author') and fields.has_key ('title'):
                         type = 'unpublished'
                         break
@@ -129,15 +137,21 @@ class ReferIterator (Iterator.Iterator):
                         
                         fields [f] = type (fields [f] [0])
                         
-                return Base.Entry (None, entry, fields)
-
+                if label:
+                
+                    key = Key.Key (None, label)
+                    return Base.Entry (key, entry, fields)
+                else:
+                    return Base.Entry (None, entry, fields)
+                
             
             t = tag_re.match (line)
             # we matched a new field start
             if t:
                 if type:
-                    
-                    if fields.has_key (type):
+                    if type == "label":
+                        label = string.join (string.split (data), ' ')
+                    elif fields.has_key (type):
                         fields [type].append (string.join (string.split (data), ' '))
                     else:
                         fields [type] = [string.join (string.split (data), ' ')]
@@ -169,8 +183,14 @@ def writer (iter, output):
             # lost their content
             if not mapping [key] [1]: continue
             field = mapping [key] [0]
-            
-            if entry.has_key (field):
+
+            if field == "label" and entry.key:
+                output.write ('%' + key + ' ')
+                output.write (Utils.format (str (entry.key.key), 75, 0, 0))
+                output.write ('\n')
+                continue
+                
+            elif entry.has_key (field):
                 type = Types.get_field (field).type
                 
                 if type == Fields.AuthorGroup:
