@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Config.py,v 1.8 2000/04/17 09:02:55 fredgo Exp $
+# $Id: Config.py,v 1.10 2000/05/12 13:19:20 fredgo Exp $
 
 from gtk import *
 from gnome.ui import *
@@ -42,7 +42,7 @@ class ConfigDialog:
         
         self.w = GnomePropertyBox ()
         self.w.set_parent (parent)
-        self.w.set_title (_("Choose you preferences"))
+        self.w.set_title (_("Choose your preferences"))
         self.w.connect ('apply', self.apply)
         self.w.set_policy (TRUE, TRUE, FALSE)
 
@@ -125,11 +125,8 @@ class ConfigDialog:
 
         if not self.warning:
             self.warning = 1
-
-            d = GnomeWarningDialog (_("Some changes require to restart Pybliographic\n"
-                                      "to be correctly taken into account"))
-            d.set_parent (self.parent)
-            d.show_all ()
+            self.parent.warning (_("Some changes require to restart Pybliographic\n"
+                                   "to be correctly taken into account"))
         return
 
 
