@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Document.py,v 1.18.2.2 2000/06/13 09:07:59 fredgo Exp $
+# $Id: Document.py,v 1.18.2.8 2000/09/25 08:16:34 fredgo Exp $
 
 ''' This module defines a Document class '''
 
@@ -215,8 +215,9 @@ class Document (Connector.Publisher):
         
         if changed != -1:
             self.changed = changed
-        
+
         self.index.display (self.selection.iterator (self.data.iterator ()))
+        
         self.update_status ()
         return
 
@@ -232,7 +233,13 @@ class Document (Connector.Publisher):
         entries = map (lambda x: x.key, self.index.selection ())
         
         if not entries:
-            entries = self.data.keys ()
+            iter    = self.selection.iterator (self.data.iterator ())
+            entries = []
+            
+            e = iter.first ()
+            while e:
+                entries.append (e.key)
+                e = iter.next ()
 
         url = Fields.URL (style)
 
@@ -501,6 +508,7 @@ class Document (Connector.Publisher):
             self.data.add (entry)
 
         self.redisplay_index ()
+        self.index.set_scroll (entries [-1])
         return
 
                 
@@ -585,18 +593,21 @@ class Document (Connector.Publisher):
         else:
             self.data.add (new)
 
-        self.redisplay_index (1)
         self.freeze_display (None)
+
+        self.redisplay_index (1)
+        self.index.select_item (new)
         return
     
     
     def delete_entry (self, * arg):
         ''' removes the selected list of items after confirmation '''
         entries = self.index.selection ()
-
         l = len (entries)
         if l == 0: return
-        
+
+        offset = self.index.get_item_position (entries [-1])
+
         if l > 1:
             question = _("Remove all the %d entries ?") % len (entries)
         else:
@@ -610,6 +621,7 @@ class Document (Connector.Publisher):
             del self.data [entry.key]
             
         self.redisplay_index (1)
+        self.index.select_item (offset)
         return
     
     
@@ -643,7 +655,14 @@ class Document (Connector.Publisher):
     
 
     def sort_by_field (self, field):
-        self.selection.sort = Sort.Sort ([Sort.FieldSort (field)])
+        if field == '-key-':
+            mode = Sort.KeySort ()
+        elif field == '-type-':
+            mode = Sort.TypeSort ()
+        else:
+            mode = Sort.FieldSort (field)
+            
+        self.selection.sort = Sort.Sort ([mode])
         self.redisplay_index ()
         return
 
@@ -691,7 +710,13 @@ class Document (Connector.Publisher):
         # 2.- Proportion betzeen list and text
         height = self.paned.children () [0].get_allocation () [3]
         config.set_int ('Pybliographic/UI/Paned', height)
-        config.sync ()
+
+        # updates the index's config
+        self.index.update_configuration ()
+
+        # ...and the search window
+        if self.search_dg:
+            self.search_dg.update_configuration ()
         return
 
     
