@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: TextUI.py,v 1.4 2000/04/17 14:57:36 fredgo Exp $
+# $Id: TextUI.py,v 1.4.2.1 2000/05/30 07:58:09 fredgo Exp $
 
 ''' This module provides basical high level functions '''
 
@@ -27,7 +27,7 @@ import os, sys, traceback, tempfile, string
 
 from Pyblio import Base, Help, Search, Types, Autoload, Fields
 from Pyblio.Selection import Selection
-from Pyblio.Open import bibopen, bibwrite
+from Pyblio.Open import bibopen, bibwrite, bibnew
 from Pyblio.Style import Utils
 
 # ----- Create elementary Test -----
